This crate contains kube-rs compatible bindings for Kubernetes custom resources for the anywhere.eks.amazonaws.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
anywhere.eks.amazonaws.com/v1alpha1
AWSDatacenterConfigAWSIamConfigBundlesCloudStackDatacenterConfigCloudStackMachineConfigClusterControlPlaneUpgradeDockerDatacenterConfigEKSAReleaseFluxConfigGitOpsConfigMachineDeploymentUpgradeNodeUpgradeNutanixDatacenterConfigNutanixMachineConfigOIDCConfigSnowDatacenterConfigSnowIPPoolSnowMachineConfigTinkerbellDatacenterConfigTinkerbellMachineConfigTinkerbellTemplateConfigVSphereDatacenterConfigVSphereMachineConfig