pub struct CloudStackMachineConfigDiskOffering {
pub custom_size_in_gb: Option<i64>,
pub device: String,
pub filesystem: String,
pub id: Option<String>,
pub label: String,
pub mount_path: String,
pub name: Option<String>,
}Expand description
DiskOffering refers to a disk offering which has been previously registered in CloudStack. It represents a disk offering with pre-defined size or custom specified disk size. It can either be specified as a UUID or name
Fields
custom_size_in_gb: Option<i64>disk size in GB, > 0 for customized disk offering; = 0 for non-customized disk offering
device: Stringdevice name of the disk offering in VM, shows up in lsblk command
filesystem: Stringfilesystem used to mkfs in disk offering partition
id: Option<String>Id of a resource in the CloudStack environment. Mutually exclusive with Name
label: Stringdisk label used to label disk partition
mount_path: Stringpath the filesystem will use to mount in VM
name: Option<String>Name of a resource in the CloudStack environment. Mutually exclusive with Id